# dataframe ---------------------------------------------------------------

#' @importFrom tibble data_frame
#' @export
tibble::data_frame

#' @importFrom tibble data_frame_
#' @export
tibble::data_frame_

#' @importFrom tibble as_data_frame
#' @export
tibble::as_data_frame

#' @importFrom tibble lst
#' @export
tibble::lst

#' @importFrom tibble lst_
#' @export
tibble::lst_

#' @importFrom tibble add_row
#' @export
tibble::add_row

# type_sum ----------------------------------------------------------------

#' @importFrom tibble type_sum
#' @export
tibble::type_sum

# glimpse -----------------------------------------------------------------

#' @importFrom tibble glimpse
#' @export
tibble::glimpse

# frame-data --------------------------------------------------------------

#' @importFrom tibble frame_data
#' @export
tibble::frame_data

#' @importFrom tibble tribble
#' @export
tibble::tribble

#' @importFrom tibble tibble
#' @export
tibble::tibble

#' @importFrom tibble as_tibble
#' @export
tibble::as_tibble

#' @importFrom tibble view
tibble::view

# utils -------------------------------------------------------------------

#' @importFrom tibble trunc_mat
#' @export
tibble::trunc_mat

#' @importFrom tibble tbl_sum
#' @export
tibble::tbl_sum
